@@ -3,7 +3,7 @@
 import pathlib
 from ctypes import *
 from . import free, calloc
-from .fmi1 import _FMU, printLogMessage
+from .fmi1 import _FMU, FMICallException, printLogMessage
 
 
 fmi2Component            = c_void_p
@@ -212,7 +212,7 @@ class _FMU2(_FMU):
             if restype == fmi2Status:  # status code
                 # check the status code
                 if res > fmi2Warning:
-                    raise Exception("%s failed with status %d." % (fname, res))
+                    raise FMICallException(function=fname, status=res)
 
             return res
 
@@ -345,12 +345,18 @@ class _FMU2(_FMU):
         self.fmi2GetFMUstate(self.component, byref(state))
         return state
 
+    getFMUState = getFMUstate  # alias for the FMI 3.0 name
+
     def setFMUstate(self, state):
         self.fmi2SetFMUstate(self.component, state)
 
+    setFMUState = setFMUstate
+
     def freeFMUstate(self, state):
         self.fmi2FreeFMUstate(self.component, byref(state))
 
+    freeFMUState = freeFMUstate
+
     def serializeFMUstate(self, state):
         """ Serialize an FMU state
 
@@ -367,7 +373,9 @@ class _FMU2(_FMU):
         self.fmi2SerializeFMUstate(self.component, state, serializedState, size)
         return serializedState.raw
 
-    def deSerializeFMUstate(self, serializedState, state=fmi2FMUstate()):
+    serializeFMUState = serializeFMUstate
+
+    def deSerializeFMUstate(self, serializedState, state=None):
         """ De-serialize an FMU state
 
         Parameters:
@@ -377,11 +385,14 @@ class _FMU2(_FMU):
         Returns:
             the de-serialized FMU state
         """
-
+        if state is None:
+            state = fmi2FMUstate()
         buffer = create_string_buffer(serializedState, size=len(serializedState))
         self.fmi2DeSerializeFMUstate(self.component, buffer, len(buffer), byref(state))
         return state
 
+    deserializeFMUState = deSerializeFMUstate
+
     # Getting partial derivatives
 
     def getDirectionalDerivative(self, vUnknown_ref, vKnown_ref, dvKnown):
@@ -572,7 +583,7 @@ class FMU2Slave(_FMU2):
         return list(value)
 
     def doStep(self, currentCommunicationPoint, communicationStepSize, noSetFMUStatePriorToCurrentPoint=fmi2True):
-        return self.fmi2DoStep(self.component, currentCommunicationPoint, communicationStepSize, noSetFMUStatePriorToCurrentPoint)
+        self.fmi2DoStep(self.component, currentCommunicationPoint, communicationStepSize, noSetFMUStatePriorToCurrentPoint)
 
     def cancelStep(self):
         self.fmi2CancelStep(self.component)
@@ -582,24 +593,24 @@ class FMU2Slave(_FMU2):
     def getStatus(self, kind):
         value = fmi2Status(fmi2OK)
         self.fmi2GetStatus(self.component, kind, byref(value))
-        return value
+        return value.value
 
     def getRealStatus(self, kind):
         value = fmi2Real(0.0)
         self.fmi2GetRealStatus(self.component, kind, byref(value))
-        return value
+        return value.value
 
     def getIntegerStatus(self, kind):
         value = fmi2Integer(0)
         self.fmi2GetIntegerStatus(self.component, kind, byref(value))
-        return value
+        return value.value
 
     def getBooleanStatus(self, kind):
         value = fmi2Boolean(fmi2False)
         self.fmi2GetBooleanStatus(self.component, kind, byref(value))
-        return value
+        return bool(value.value)
 
     def getStringStatus(self, kind):
         value = fmi2String(b'')
         self.fmi2GetStringStatus(self.component, kind, byref(value))
-        return value
+        return value.value.decode('utf-8')
